Skip to contents

Functions listed below are deprecated and will be removed in a future version. Where possible, alternatives are mentioned. Help pages for deprecated functions are available at help("<function>-deprecated").

Usage

makeGrid(
  size = NULL,
  n.lon = NULL,
  n.lat = NULL,
  lon.range = NULL,
  lat.range = NULL
)

extractFromLayer(x, ...)

Value

NULL.

makeGrid

For makeGrid, use makeSquareGrid.

extractFromLayer

For extractFromLayer, use assignByPolygon.

Examples

if (FALSE) { # \dontrun{
# these functions are deprecated — use the replacements instead:
# makeGrid()       -> makeSquareGrid()
# extractFromLayer() -> assignByPolygon()
} # }