This function finds the shortest path between nodes in a graph using Dijkstra's algorithm. It can be applied to both gGraph and gData objects.
Usage
dijkstraBetween(x, ...)
# S4 method for class 'gGraph'
dijkstraBetween(x, from, to)
# S4 method for class 'gData'
dijkstraBetween(x)Value
A gPath object.
Details
The function uses the RBGL package to compute the shortest paths. It checks for the connectivity of the graph and handles cases where there are duplicated paths.
See also
Other dijkstra_methods:
dijkstraBuffer(),
dijkstraFrom(),
gPath2dist()