This function tests whether a gGraph has heterogeneous
costs associated to its edges.
Arguments
- x
a valid
gGraphobject.
Details
This low-level function is designed to be called by other procedures of
geoGraph. However, it can sometimes be useful by itself. Note that a gGraph
with all costs set uniform will also result in FALSE.
Unlike other functions in geoGraph, this function does not
test for the validity of the provided arguments (for speed purposes).
See also
Other cost_functions:
combineCosts(),
dropCosts(),
getCosts(),
setCosts(),
setDistCosts()