Usage
# S4 method for class 'gData'
isConnected(object, ...)
# S4 method for class 'gGraph'
isConnected(object, ...)Details
This function is a method for both gData and gGraph objects.
For a gData object, it tests if all the nodes in the object form a
connected set on the associated gGraph object. For a gGraph
object, it tests if all nodes in the graph form a connected set.
Use areConnected() if you want to test if a specific subset
of nodes form a connected set.
See also
Other connectivity_functions:
areConnected(),
areNeighbours(),
isReachable()